scNym Documentation — scNym 0.2.0 documentation

# scNym Documentation

## Installation

Install scNym with pip:

    pip install scnym

## Tutorials

The best way to become acquainted with scNym is to walk through one of our interactive tutorials.

- Tutorials
  - Semi-supervised cell type classification using cell atlas references
  - Classifying cell types with pre-trained scNym models

## API Level Documentation

- Module Documentation
  - Interactive API: api
  - Advanced Interface
    - Model Specification
    - Model Trainer
    - Model Interpretation
    - Data Loaders

# Indices and tables

- Index

- Module Index

- Search Page